@@ -1,7 +1,7 @@
 /*
  * This file is part of sidplayfp, a console SID player.
  *
- * Copyright 2011-2023 Leandro Nini
+ * Copyright 2011-2025 Leandro Nini
  * Copyright 2000-2001 Simon White
  *
  * This program is free software; you can redistribute it and/or modify
@@ -168,10 +168,7 @@ int ConsolePlayer::args(int argc, const char *argv[])
     m_driver.file   = false;
     m_driver.info   = false;
 
-    for (int i=0; i<9; i++)
-    {
-        vMute[i] = false;
-    }
+    m_mute_channel.reset();
 
     int  infile = 0;
     int  i      = 0;
@@ -204,13 +201,11 @@ int ConsolePlayer::args(int argc, const char *argv[])
                 if (!parseAddress (&argv[i][3], m_engCfg.secondSidAddress))
                     err = true;
             }
-#ifdef FEAT_THIRD_SID
             else if (strncmp (&argv[i][1], "ts", 2) == 0)
             {   // Override sidTune and enable the third sid
                 if (!parseAddress (&argv[i][3], m_engCfg.thirdSidAddress))
                     err = true;
             }
-#endif
             else if (argv[i][1] == 'f')
             {
                 if (argv[i][2] == '\0')
@@ -256,12 +251,26 @@ int ConsolePlayer::args(int argc, const char *argv[])
                     err = true;
                 else
                 {
-                    const int voice = atoi(&argv[i][2]);
-                    if (voice > 0 && voice <= 9)
-                        vMute[voice-1] = true;
+                    const unsigned int voice = atoi(&argv[i][2]);
+                    if (voice > 0 && voice <= m_mute_channel.size())
+                        m_mute_channel[voice-1] = true;
                 }
             }
 
+#ifdef FEAT_SAMPLE_MUTE
+            // Sample muting
+            else if (argv[i][1] == 'g')
+            {
+                if (argv[i][2] == '\0')
+                    err = true;
+                else
+                {
+                    const unsigned int chip = atoi(&argv[i][2]);
+                    if (chip > 0 && chip <= m_mute_samples.size())
+                        m_mute_samples[chip-1] = true;
+                }
+            }
+#endif
             else if (argv[i][1] == 'p')
             {   // User forgot precision
                 if (argv[i][2] == '\0')
@@ -339,12 +348,11 @@ int ConsolePlayer::args(int argc, const char *argv[])
                 m_channels = 1;
             }
 
-#ifdef FEAT_DIGIBOOST
             else if (std::strcmp (&argv[i][1], "-digiboost") == 0)
             {
                 m_engCfg.digiBoost = true;
             }
-#endif
+
             // Video/Verbose Options
             else if (std::strcmp (&argv[i][1], "vnf") == 0)
             {
@@ -390,6 +398,33 @@ int ConsolePlayer::args(int argc, const char *argv[])
                     m_fcurve = atof(&argv[i][9]);
                 }
             }
+#ifdef FEAT_FILTER_RANGE
+            else if (strncmp (&argv[i][1], "-frange=", 8) == 0)
+            {
+                if (strncmp (&argv[i][9], "auto", 4) == 0)
+                {
+                    m_autofilter = true;
+                }
+                else
+                {
+                    m_frange = atof(&argv[i][9]);
+                }
+            }
+#endif
+#ifdef FEAT_CW_STRENGTH
+            else if (std::strcmp (&argv[i][1], "cww") == 0)
+            {
+                m_combinedWaveformsStrength  = SidConfig::WEAK;
+            }
+            else if (std::strcmp (&argv[i][1], "cwa") == 0)
+            {
+                m_combinedWaveformsStrength  = SidConfig::AVERAGE;
+            }
+            else if (std::strcmp (&argv[i][1], "cws") == 0)
+            {
+                m_combinedWaveformsStrength  = SidConfig::STRONG;
+            }	
+#endif
             // File format conversions
             else if (argv[i][1] == 'w')
             {
@@ -632,12 +667,12 @@ void ConsolePlayer::displayArgs (const char *arg)
         << " -f<num>      set frequency in Hz (default: "
         << SidConfig::DEFAULT_SAMPLING_FREQ << ")" << endl
         << " -ds<addr>    set second sid address (e.g. -ds0xd420)" << endl
-#ifdef FEAT_THIRD_SID
         << " -ts<addr>    set third sid address (e.g. -ts0xd440)" << endl
-#endif
 
         << " -u<num>      mute voice <num> (e.g. -u1 -u2)" << endl
-
+#ifdef FEAT_SAMPLE_MUTE
+        << " -g<num>      mute samples <num> (e.g. -g1 -g2)" << endl
+#endif
         << " -nf          no SID filter emulation" << endl
 
         << " -o<l|s>[num] looping and/or single track" << endl
@@ -657,13 +692,16 @@ void ConsolePlayer::displayArgs (const char *arg)
 
         << " -m<o|n>[f]   set SID new/old chip model (default: old)" << endl
         << "              Use 'f' to force the model" << endl
-#ifdef FEAT_DIGIBOOST
         << " --digiboost  Enable digiboost for 8580 model" << endl
-#endif
         << " -r[i|r][f]   set resampling method (default: resample interpolate)" << endl
         << "              Use 'f' to enable fast resampling (only for reSID)" << endl
         << " --fcurve=<num>|auto Controls the filter curve in the ReSIDfp emulation (0.0 to 1.0, default: 0.5)" << endl
-
+#ifdef FEAT_FILTER_RANGE
+        << " --frange=<num>|auto Controls the filter range in the ReSIDfp emulation (0.0 to 1.0, default: 0.5)" << endl
+#endif
+#ifdef FEAT_CW_STRENGTH
+        << " -cw<w|a|s>   Set the strength of combined waveforms, w(eak), a(verage) or s(trong)" << endl
+#endif
         << " -w[name]     create wav file (default: <datafile>[n].wav)" << endl
         << " --au[name]   create au file (default: <datafile>[n].au)" << endl
         << " --info       add metadata to wav file" << endl;
