@@ -366,9 +366,7 @@ ConsolePlayer::ConsolePlayer (const char * const name) :
         m_engCfg.defaultC64Model = emulation.modelDefault;
         m_engCfg.defaultSidModel = emulation.sidModel;
         m_engCfg.forceSidModel   = emulation.forceModel;
-#ifdef FEAT_CONFIG_CIAMODEL
         m_engCfg.ciaModel        = emulation.ciaModel;
-#endif
         m_engCfg.frequency    = audio.frequency;
         m_engCfg.samplingMethod = emulation.samplingMethod;
         m_engCfg.fastSampling = emulation.fastSampling;
@@ -810,9 +808,10 @@ bool ConsolePlayer::open (void)
     }
 
 #ifdef FEAT_FILTER_DISABLE
-    m_engine.filter(0, m_filter.enabled);
-    m_engine.filter(1, m_filter.enabled);
-    m_engine.filter(2, m_filter.enabled);
+    for (int chip=0; chip<3; chip++)
+    {
+        m_engine.filter(chip, m_filter.enabled);
+    }
 #endif
 #ifdef FEAT_REGS_DUMP_SID
     if (
@@ -826,36 +825,38 @@ bool ConsolePlayer::open (void)
     else
         m_freqTable = freqTablePal;
 #endif
+#ifdef FEAT_NEW_PLAY_API
+    m_mixer.initialize(m_engine.installedSIDs(), m_engCfg.playback == SidConfig::STEREO);
+#endif
+
     // Start the player.  Do this by fast
     // forwarding to the start position
     m_driver.selected = &m_driver.null;
     m_speed.current   = m_speed.max;
-    m_engine.fastForward (100 * m_speed.current);
-
-    m_engine.mute(0, 0, m_mute_channel[0]);
-    m_engine.mute(0, 1, m_mute_channel[1]);
-    m_engine.mute(0, 2, m_mute_channel[2]);
-    m_engine.mute(1, 0, m_mute_channel[3]);
-    m_engine.mute(1, 1, m_mute_channel[4]);
-    m_engine.mute(1, 2, m_mute_channel[5]);
-    m_engine.mute(2, 0, m_mute_channel[6]);
-    m_engine.mute(2, 1, m_mute_channel[7]);
-    m_engine.mute(2, 2, m_mute_channel[8]);
-#ifdef FEAT_SAMPLE_MUTE
-    m_engine.mute(0, 3, m_mute_samples[0]);
-    m_engine.mute(1, 3, m_mute_samples[1]);
-    m_engine.mute(2, 3, m_mute_samples[2]);
+#ifdef FEAT_NEW_PLAY_API
+    m_mixer.setFastForward(m_speed.current);
+#else
+    m_engine.fastForward(100 * m_speed.current);
 #endif
 
+    for (int chip=0; chip<3; chip++)
+    {
+        for (int channel=0; channel<3; channel++)
+        {
+            m_engine.mute(chip, channel, m_mute_channel[chip*3 + channel]);
+        }
+#ifdef FEAT_SAMPLE_MUTE
+        m_engine.mute(chip, 3, m_mute_samples[chip]);
+#endif
+    }
+
     // As yet we don't have a required songlength
     // so try the songlength database or keep the default
     if (!m_timer.valid)
     {
-#ifdef FEAT_NEW_SONLEGTH_DB
-        const int_least32_t length = songlengthDB == sldb_t::MD5 ? m_database.lengthMs(m_tune) : (m_database.length(m_tune) * 1000);
-#else
-        const int_least32_t length = m_database.length(m_tune) * 1000;
-#endif
+        const int_least32_t length = songlengthDB == sldb_t::MD5
+            ? m_database.lengthMs(m_tune)
+            : (m_database.length(m_tune) * 1000);
         if (length > 0)
             m_timer.length = length;
     }
@@ -938,12 +939,11 @@ void ConsolePlayer::emuflush ()
     }
 }
 
-
 // Out play loop to be externally called
 bool ConsolePlayer::play()
 {
     uint_least32_t frames = 0;
-    if (m_state == playerRunning)
+    if (m_state == playerRunning) LIKELY
     {
         updateDisplay();
 
@@ -952,8 +952,32 @@ bool ConsolePlayer::play()
         // multiply by number of channels to get the count of 16bit samples
         const uint_least32_t length = getBufSize() * m_driver.cfg.channels;
         short *buffer = m_driver.selected->buffer();
+#ifdef FEAT_NEW_PLAY_API
+        m_mixer.begin(buffer, length);
+        short* buffers[3];
+        m_engine.buffers(buffers);
+
+        do
+        {
+            int samples = m_engine.play(2000);
+            if (samples < 0) UNLIKELY
+            {
+                cerr << m_engine.error();
+                m_state = playerError;
+                return false;
+            }
+            if (samples > 0)
+                m_mixer.doMix(buffers, samples);
+            else break;
+        }
+        while (!m_mixer.isFull());
+
+        // m_engine.play returns the number of 16bit samples
+        // divide by number of channels to get the count of frames
+        frames = length / m_driver.cfg.channels;
+#else
         uint_least32_t samples = m_engine.play(buffer, length);
-        if ((samples < length) || !m_engine.isPlaying())
+        if ((samples < length) || !m_engine.isPlaying()) UNLIKELY
         {
             cerr << m_engine.error();
             m_state = playerError;
@@ -962,6 +986,7 @@ bool ConsolePlayer::play()
         // m_engine.play returns the number of 16bit samples
         // divide by number of channels to get the count of frames
         frames = samples / m_driver.cfg.channels;
+#endif
     }
 #ifdef HAVE_UNISTD_H
     else
@@ -970,8 +995,8 @@ bool ConsolePlayer::play()
 
     switch (m_state)
     {
-    case playerRunning:
-        if (!m_driver.selected->write(frames))
+    LIKELY case playerRunning:
+        if (!m_driver.selected->write(frames)) UNLIKELY
         {
             cerr << m_driver.selected->getErrorString();
             m_state = playerError;
@@ -1025,17 +1050,22 @@ void ConsolePlayer::stop ()
 
 uint_least32_t ConsolePlayer::getBufSize()
 {
-    if (m_timer.starting && (m_timer.current >= m_timer.start))
+    if (m_timer.starting && (m_timer.current >= m_timer.start)) UNLIKELY
     {   // Switch audio drivers.
         m_timer.starting = false;
         m_driver.selected = m_driver.device;
         m_driver.selected->clearBuffer();
-        m_speed.current = 1;
+#ifdef FEAT_NEW_PLAY_API
+        m_mixer.clear();
+        m_mixer.setFastForward(1);
+#else
         m_engine.fastForward(100);
+#endif
+        m_speed.current = 1;
         if (m_cpudebug)
             m_engine.debug (true, nullptr);
     }
-    else if ((m_timer.stop != 0) && (m_timer.current >= m_timer.stop))
+    else if ((m_timer.stop != 0) && (m_timer.current >= m_timer.stop)) UNLIKELY
     {
         m_state = playerExit;
         if (m_track.loop)
@@ -1070,13 +1100,8 @@ uint_least32_t ConsolePlayer::getBufSize()
 // External Timer Event
 void ConsolePlayer::updateDisplay()
 {
-#ifdef FEAT_NEW_SONLEGTH_DB
     const uint_least32_t milliseconds = m_engine.timeMs();
     const uint_least32_t seconds = milliseconds / 1000;
-#else
-    const uint_least32_t seconds = m_engine.time();
-    const uint_least32_t milliseconds = seconds * 1000;
-#endif
 
     refreshRegDump();
 
@@ -1122,11 +1147,7 @@ void ConsolePlayer::decodeKeys ()
             if (!m_track.single)
             {   // Only select previous song if less than timeout
                 // else restart current song
-#ifdef FEAT_NEW_SONLEGTH_DB
-    const uint_least32_t milliseconds = m_engine.timeMs();
-#else
-    const uint_least32_t milliseconds = m_engine.time() * 1000;
-#endif
+                const uint_least32_t milliseconds = m_engine.timeMs();
                 if (milliseconds < SID2_PREV_SONG_TIMEOUT)
                 {
                     m_track.selected--;
@@ -1136,17 +1157,25 @@ void ConsolePlayer::decodeKeys ()
             }
         break;
 
-        case A_UP_ARROW:     
+        case A_UP_ARROW:
             m_speed.current *= 2;
             if (m_speed.current > m_speed.max)
                 m_speed.current = m_speed.max;
-  
-            m_engine.fastForward (100 * m_speed.current);
+
+#ifdef FEAT_NEW_PLAY_API
+            m_mixer.setFastForward(m_speed.current);
+#else
+            m_engine.fastForward(100 * m_speed.current);
+#endif
         break;
 
         case A_DOWN_ARROW:
             m_speed.current = 1;
-            m_engine.fastForward (100);
+#ifdef FEAT_NEW_PLAY_API
+            m_mixer.setFastForward(1);
+#else
+            m_engine.fastForward(100);
+#endif
         break;
 
         case A_HOME:
@@ -1237,9 +1266,10 @@ void ConsolePlayer::decodeKeys ()
         case A_TOGGLE_FILTER:
             m_filter.enabled = !m_filter.enabled;
 #ifdef FEAT_FILTER_DISABLE
-            m_engine.filter(0, m_filter.enabled);
-            m_engine.filter(1, m_filter.enabled);
-            m_engine.filter(2, m_filter.enabled);
+        for (int chip=0; chip<3; chip++)
+        {
+            m_engine.filter(chip, m_filter.enabled);
+        }
 #else
             m_engCfg.sidEmulation->filter(m_filter.enabled);
 #endif
